SplitLayoutSettings

Struct SplitLayoutSettings 

pub struct SplitLayoutSettings {
Show 14 fields pub border: f64, pub center_min_size: [f64; 2], pub left_value: f64, pub left_min_value: f64, pub right_value: f64, pub right_min_value: f64, pub top_value: f64, pub top_min_value: f64, pub bottom_value: f64, pub bottom_min_value: f64, pub lock_left: bool, pub lock_right: bool, pub lock_top: bool, pub lock_bottom: bool,
}
Stores split layout settings.

Fields

border: f64

The border width.

center_min_size: [f64; 2]

The minimum size of center.

left_value: f64

The initial value for left split.

left_min_value: f64

The minimum value for left split.

right_value: f64

The initial value for right split.

right_min_value: f64

The minimum value for right split.

top_value: f64

The initial value for top split.

top_min_value: f64

The minimum value for top split.

bottom_value: f64

The initial value for bottom split.

bottom_min_value: f64

The minimum value for bottom split.

lock_left: bool

Locks left split.

lock_right: bool

Locks right split.

lock_top: bool

Locks top split.

lock_bottom: bool

Locks bottom split.

Implementations

Source

impl SplitLayoutSettings

pub fn new(border: f64, min_value: f64) -> SplitLayoutSettings

Creates a new SplitLayoutSettings object with values set to minimum.

Work area minimum size is set to 1x1.

pub fn left(self, value: f64, min_value: f64) -> SplitLayoutSettings

Set the value and minimum value for left split.

pub fn right(self, value: f64, min_value: f64) -> SplitLayoutSettings

Sets the value and minimum value for right split.

pub fn top(self, value: f64, min_value: f64) -> SplitLayoutSettings

Sets the value and minimum value for top split.

pub fn bottom(self, value: f64, min_value: f64) -> SplitLayoutSettings

Sets the value and minimum value for bottom split.

pub fn lock_left(self, value: f64) -> SplitLayoutSettings

Locks left split, sets the minimum value at the same time.

pub fn lock_right(self, value: f64) -> SplitLayoutSettings

Locks right split, sets the minimum value at the same time.

pub fn lock_top(self, value: f64) -> SplitLayoutSettings

Locks top split, sets the minimum value at the same time.

pub fn lock_bottom(self, value: f64) -> SplitLayoutSettings

Locks bottom split, sets the minimum value at the same time.